#[repr(i32)]pub enum PlacementStrategy {
LeastJobs = 0,
Pinned = 1,
}Variants
Implementations
Sourceimpl PlacementStrategy
impl PlacementStrategy
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of PlacementStrategy.
Sourcepub fn from_i32(value: i32) -> Option<PlacementStrategy>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<PlacementStrategy>
Use the TryFrom<i32> implementation instead
Converts an i32 to a PlacementStrategy, or None if value is not a valid variant.