Command

Enum Command 

pub enum Command {
Show 20 variants ListJobs(ListJobs), StartJob(StartJob), DrainJob(DrainJob), StopJob(StopJob), RestartJob(RestartJob), JobStatus(JobStatusRequest), SubscribeEvents(SubscribeEvents), SubscribeMetrics(SubscribeMetrics), GetConfig(GetConfig), PutConfig(PutConfig), ListClusterJobs(ListClusterJobs), ClusterNodeInfo(ClusterNodeInfo), SubmitClusterJob(SubmitClusterJob), RememberClusterAssignment(RememberClusterAssignment), AllocateShard(ShardAllocationRequest), RememberShardAllocations(RememberShardAllocations), GetShardAllocations(GetShardAllocations), ForwardShardEnvelopes(ForwardShardEnvelopes), CompleteShardingAsk(CompleteShardingAsk), OpenShardPipe(OpenShardPipe),
}

Variants



ListJobs(ListJobs)



StartJob(StartJob)



DrainJob(DrainJob)



StopJob(StopJob)



RestartJob(RestartJob)



JobStatus(JobStatusRequest)



SubscribeEvents(SubscribeEvents)



SubscribeMetrics(SubscribeMetrics)



GetConfig(GetConfig)



PutConfig(PutConfig)



ListClusterJobs(ListClusterJobs)



ClusterNodeInfo(ClusterNodeInfo)



SubmitClusterJob(SubmitClusterJob)



RememberClusterAssignment(RememberClusterAssignment)



AllocateShard(ShardAllocationRequest)



RememberShardAllocations(RememberShardAllocations)



GetShardAllocations(GetShardAllocations)



ForwardShardEnvelopes(ForwardShardEnvelopes)



CompleteShardingAsk(CompleteShardingAsk)



OpenShardPipe(OpenShardPipe)

Implementations

Source

impl Command

pub fn encode(&self, buf: &mut impl BufMut)

Encodes the message to a buffer.

pub fn merge( field: &mut Option<Command>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>

Decodes an instance of the message from a buffer, and merges it into self.

pub fn encoded_len(&self) -> usize

Returns the encoded length of the message without a length delimiter.