pub struct PlacementSpec {
pub role_constraint: String,
pub strategy: i32,
pub pinned_node_id: String,
}Fields
role_constraint: Stringstrategy: i32pinned_node_id: StringImplementations
Sourceimpl PlacementSpec
impl PlacementSpec
Sourcepub fn strategy(&self) -> PlacementStrategy
pub fn strategy(&self) -> PlacementStrategy
Returns the enum value of strategy, or the default if the field is set to an invalid enum value.
Sourcepub fn set_strategy(&mut self, value: PlacementStrategy)
pub fn set_strategy(&mut self, value: PlacementStrategy)
Sets strategy to the provided enum value.