pub struct DcpServer { /* private fields */ }Implementations
Sourceimpl DcpServer
impl DcpServer
pub fn new( registry: JobRegistryHandle, instrumentation: StreamInstrumentationRegistry, factories: DcpJobFactories, config: DcpServerConfig, ) -> Self
pub fn from_agent( agent: &AgentHandle, factories: DcpJobFactories, config: DcpServerConfig, ) -> Self
Sourcepub fn set_cluster_view(&self, provider: Arc<dyn ClusterViewProvider>)
pub fn set_cluster_view(&self, provider: Arc<dyn ClusterViewProvider>)
Install or replace the provider used for cluster-wide read-only DCP requests.
Sourcepub fn clear_cluster_view(&self)
pub fn clear_cluster_view(&self)
Remove the cluster view provider. Cluster DCP requests will fail until a provider is installed again.
Sourcepub fn set_sharding_view(&self, provider: Arc<dyn ShardingViewProvider>)
pub fn set_sharding_view(&self, provider: Arc<dyn ShardingViewProvider>)
Install or replace the provider used for cluster-sharding DCP requests.
Sourcepub fn clear_sharding_view(&self)
pub fn clear_sharding_view(&self)
Remove the sharding provider. Sharding DCP requests will fail until a provider is installed again.
pub async fn start(&self) -> DcpResult<DcpServerHandle>