pub struct JobContext { /* private fields */ }Expand description
Context passed to a job blueprint factory for one materialized generation.
Implementations
Sourceimpl JobContext
impl JobContext
pub fn name(&self) -> &str
pub fn job_id(&self) -> JobId
pub fn generation(&self) -> u64
pub fn kill_switch(&self) -> SharedKillSwitch
pub fn instrumentation_registry(&self) -> &StreamInstrumentationRegistry
Sourcepub fn drain_flow<T: Send + 'static>(&self) -> Flow<T, T, SharedKillSwitch>
pub fn drain_flow<T: Send + 'static>(&self) -> Flow<T, T, SharedKillSwitch>
Return a flow backed by the agent-owned shared kill switch.
Graph factories should wire this flow into the job path when graceful drain is supported.
pub fn control(&self) -> JobControl