pub enum Command {
Show 20 variants
ListJobs(ListJobs),
StartJob(StartJob),
DrainJob(DrainJob),
StopJob(StopJob),
RestartJob(RestartJob),
JobStatus(JobStatusRequest),
SubscribeEvents(SubscribeEvents),
SubscribeMetrics(SubscribeMetrics),
GetConfig(GetConfig),
PutConfig(PutConfig),
ListClusterJobs(ListClusterJobs),
ClusterNodeInfo(ClusterNodeInfo),
SubmitClusterJob(SubmitClusterJob),
RememberClusterAssignment(RememberClusterAssignment),
AllocateShard(ShardAllocationRequest),
RememberShardAllocations(RememberShardAllocations),
GetShardAllocations(GetShardAllocations),
ForwardShardEnvelopes(ForwardShardEnvelopes),
CompleteShardingAsk(CompleteShardingAsk),
OpenShardPipe(OpenShardPipe),
}Variants
ListJobs(ListJobs)
StartJob(StartJob)
DrainJob(DrainJob)
StopJob(StopJob)
RestartJob(RestartJob)
JobStatus(JobStatusRequest)
SubscribeEvents(SubscribeEvents)
SubscribeMetrics(SubscribeMetrics)
GetConfig(GetConfig)
PutConfig(PutConfig)
ListClusterJobs(ListClusterJobs)
ClusterNodeInfo(ClusterNodeInfo)
SubmitClusterJob(SubmitClusterJob)
RememberClusterAssignment(RememberClusterAssignment)
AllocateShard(ShardAllocationRequest)
RememberShardAllocations(RememberShardAllocations)
GetShardAllocations(GetShardAllocations)
ForwardShardEnvelopes(ForwardShardEnvelopes)
CompleteShardingAsk(CompleteShardingAsk)
OpenShardPipe(OpenShardPipe)
Implementations
Sourceimpl Command
impl Command
Sourcepub fn merge(
field: &mut Option<Command>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<Command>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.